==> tgam-patterns-2.0.79.tgz: package/patterns/javascripts/scroll-menu.js <==
/**
 * js logic specific to scrolling menu with arrow elements
 */

const moveStartSpeed = 2;
const speedMultiplier = 1.25;
const maxMoveSpeed = 12;
const intervalTime = 50;
const arrowLeftSelector = ".c-scroll-menu__arrow--left";
const arrowRightSelector = ".c-scroll-menu__arrow--right";
const menuListSelector = ".c-scroll-menu__list";

export default {

  /**
   * @method init
   * @description init method, adds event listener for scroll and resize
   * @param rootElement {HTMLElement} an element which will be the scope of the querySelector method
   * @return {void}
   */
  init(rootElement) {
    this.menuList = rootElement.querySelector(menuListSelector);
    this.arrowLeft = rootElement.querySelector(arrowLeftSelector);
    this.arrowRight = rootElement.querySelector(arrowRightSelector);
    this.moveSpeed = moveStartSpeed;
    this.scrollInterval = null;

    // scrolling menu event handlers
    if (this.menuList && this.arrowLeft && this.arrowRight) {
      // We need to bind these functions so that "this" references the parent object
      this.boundOnLeftArrowTouch = this.onLeftArrowTouch.bind(this);
      this.boundOnLeftArrowRelease = this.onLeftArrowRelease.bind(this);
      this.boundOnRightArrowTouch = this.onRightArrowTouch.bind(this);
      this.boundOnRightArrowRelease = this.onRightArrowRelease.bind(this);
      // left arrow click
      this.arrowLeft.addEventListener("mousedown", this.boundOnLeftArrowTouch);
      this.arrowLeft.addEventListener("touchstart", this.boundOnLeftArrowTouch);
      // left arrow release
      this.arrowLeft.addEventListener("mouseup", this.boundOnLeftArrowRelease);
      this.arrowLeft.addEventListener("mouseleave", this.boundOnLeftArrowRelease);
      this.arrowLeft.addEventListener("touchend", this.boundOnLeftArrowRelease);
      this.arrowLeft.addEventListener("touchcancel", this.boundOnLeftArrowRelease);
      // right arrow click
      this.arrowRight.addEventListener("mousedown", this.boundOnRightArrowTouch);
      this.arrowRight.addEventListener("touchstart", this.boundOnRightArrowTouch);
      // right arrow release
      this.arrowRight.addEventListener("mouseup", this.boundOnRightArrowRelease);
      this.arrowRight.addEventListener("mouseleave", this.boundOnRightArrowRelease);
      this.arrowRight.addEventListener("touchend", this.boundOnRightArrowRelease);
      this.arrowRight.addEventListener("touchcancel", this.boundOnRightArrowRelease);
    }
  },

  onLeftArrowTouch(e) {
    this.cancelInterval();
    this.scrollInterval = setInterval(() => {
      this.scrollMenuLeft();
    }, intervalTime);
  },

  onLeftArrowRelease(e) {
    this.cancelInterval();
  },

  onRightArrowTouch(e) {
    this.cancelInterval();
    this.scrollInterval = setInterval(() => {
      this.scrollMenuRight();
    }, intervalTime);
  },

  onRightArrowRelease(e) {
    this.cancelInterval();
  },

  /**
   * @method scrollMenuLeft
   * @description the speed increases the longer you hold the button
   * @return {void}
   */
  scrollMenuLeft() {
    this.moveSpeed *= speedMultiplier;
    this.moveSpeed > maxMoveSpeed && (this.moveSpeed = maxMoveSpeed);
    this.menuList.scrollLeft += this.moveSpeed;
  },

  /**
   * @method scrollMenuRight
   * @description the speed increases the longer you hold the button
   * @return {void}
   */
  scrollMenuRight() {
    this.moveSpeed *= speedMultiplier;
    this.moveSpeed > maxMoveSpeed && (this.moveSpeed = maxMoveSpeed);
    this.menuList.scrollLeft -= this.moveSpeed;
  },

  /**
   * @method cancelInterval
   * @description cancels interval for scrolling
   * @return {void}
   */
  cancelInterval() {
    this.moveSpeed = moveStartSpeed;
    clearInterval(this.scrollInterval);
  }
};

==> tgam-patterns-2.0.97.tgz: package/patterns/javascripts/scroll-menu.js <==
/**
 * js logic specific to scrolling menu with arrow elements
 */

const moveStartSpeed = 2;
const speedMultiplier = 1.11;
const maxMoveSpeed = 20;
const intervalTime = 50;
const arrowLeftSelector = ".c-scroll-menu__arrow--left";
const arrowRightSelector = ".c-scroll-menu__arrow--right";
const menuListSelector = ".c-scroll-menu__list";
const navSelector = ".c-scroll-menu__nav";

export default {

  /**
   * @method init
   * @description init method, adds event listener for scroll and resize
   * @param rootElement {HTMLElement} an element which will be the scope of the querySelector method
   * @return {void}
   */
  init(rootElement) {
    this.menuList = rootElement.querySelector(menuListSelector);
    this.navContainer = rootElement.querySelector(navSelector);
    this.arrowLeft = rootElement.querySelector(arrowLeftSelector);
    this.arrowRight = rootElement.querySelector(arrowRightSelector);
    this.moveSpeed = moveStartSpeed;
    this.scrollInterval = null;

    const scrollWidth = this.menuList.scrollWidth;
    const navWidth = this.navContainer.getBoundingClientRect().width;
    const requiresArrows = navWidth < scrollWidth;

    if (requiresArrows) {
      // TODO something if arrows are not required
    }

    // scrolling menu event handlers
    if (this.menuList && this.arrowLeft && this.arrowRight) {
      // We need to bind these functions so that "this" references the parent object
      this.boundOnLeftArrowTouch = this.onLeftArrowTouch.bind(this);
      this.boundOnLeftArrowRelease = this.onLeftArrowRelease.bind(this);
      this.boundOnRightArrowTouch = this.onRightArrowTouch.bind(this);
      this.boundOnRightArrowRelease = this.onRightArrowRelease.bind(this);

      // left arrow click
      this.arrowLeft.addEventListener("mousedown", this.boundOnLeftArrowTouch);
      this.arrowLeft.addEventListener("touchstart", this.boundOnLeftArrowTouch);

      // left arrow release
      this.arrowLeft.addEventListener("mouseup", this.boundOnLeftArrowRelease);
      this.arrowLeft.addEventListener("mouseleave", this.boundOnLeftArrowRelease);
      this.arrowLeft.addEventListener("touchend", this.boundOnLeftArrowRelease);
      this.arrowLeft.addEventListener("touchcancel", this.boundOnLeftArrowRelease);

      // right arrow click
      this.arrowRight.addEventListener("mousedown", this.boundOnRightArrowTouch);
      this.arrowRight.addEventListener("touchstart", this.boundOnRightArrowTouch);

      // right arrow release
      this.arrowRight.addEventListener("mouseup", this.boundOnRightArrowRelease);
      this.arrowRight.addEventListener("mouseleave", this.boundOnRightArrowRelease);
      this.arrowRight.addEventListener("touchend", this.boundOnRightArrowRelease);
      this.arrowRight.addEventListener("touchcancel", this.boundOnRightArrowRelease);
    }
  },

  /**
   * @method onLeftArrowTouch
   * @description TODO
   * @return {void}
   */
  onLeftArrowTouch() {
    this.cancelInterval();
    this.scrollInterval = setInterval(() => {
      this.scrollMenuRight();
    }, intervalTime);
  },

  /**
   * @method onLeftArrowRelease
   * @description TODO
   * @return {void}
   */
  onLeftArrowRelease() {
    this.cancelInterval();
  },

  /**
   * @method onRightArrowTouch
   * @description TODO
   * @return {void}
   */
  onRightArrowTouch() {
    this.cancelInterval();
    this.scrollInterval = setInterval(() => {
      this.scrollMenuLeft();
    }, intervalTime);
  },

  /**
   * @method onRightArrowRelease
   * @description TODO
   * @return {void}
   */
  onRightArrowRelease() {
    this.cancelInterval();
  },

  /**
   * @method scrollMenuLeft
   * @description the speed increases the longer you hold the button
   * @return {void}
   */
  scrollMenuLeft() {
    this.moveSpeed *= speedMultiplier;
    this.moveSpeed > maxMoveSpeed && (this.moveSpeed = maxMoveSpeed);
    this.menuList.scrollLeft += this.moveSpeed;
  },

  /**
   * @method scrollMenuRight
   * @description the speed increases the longer you hold the button
   * @return {void}
   */
  scrollMenuRight() {
    this.moveSpeed *= speedMultiplier;
    this.moveSpeed > maxMoveSpeed && (this.moveSpeed = maxMoveSpeed);
    this.menuList.scrollLeft -= this.moveSpeed;
  },

  /**
   * @method cancelInterval
   * @description cancels interval for scrolling
   * @return {void}
   */
  cancelInterval() {
    this.moveSpeed = moveStartSpeed;
    clearInterval(this.scrollInterval);
  }
};
